# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCloudKeystoreResult',
    'AwaitableGetCloudKeystoreResult',
    'get_cloud_keystore',
    'get_cloud_keystore_output',
]

@pulumi.output_type
class GetCloudKeystoreResult:
    """
    A collection of values returned by getCloudKeystore.
    """
    def __init__(__self__, cloud_provider_id=None, id=None, machine_identities_count=None, name=None, type=None):
        if cloud_provider_id and not isinstance(cloud_provider_id, str):
            raise TypeError("Expected argument 'cloud_provider_id' to be a str")
        pulumi.set(__self__, "cloud_provider_id", cloud_provider_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if machine_identities_count and not isinstance(machine_identities_count, int):
            raise TypeError("Expected argument 'machine_identities_count' to be a int")
        pulumi.set(__self__, "machine_identities_count", machine_identities_count)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="cloudProviderId")
    def cloud_provider_id(self) -> _builtins.str:
        return pulumi.get(self, "cloud_provider_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="machineIdentitiesCount")
    def machine_identities_count(self) -> _builtins.int:
        """
        Number of machine identities provisioned to the cloud keystore.
        """
        return pulumi.get(self, "machine_identities_count")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The cloud keystore type. Either `ACM`, `AKV` or `GCM`.
        """
        return pulumi.get(self, "type")


class AwaitableGetCloudKeystoreResult(GetCloudKeystoreResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudKeystoreResult(
            cloud_provider_id=self.cloud_provider_id,
            id=self.id,
            machine_identities_count=self.machine_identities_count,
            name=self.name,
            type=self.type)


def get_cloud_keystore(cloud_provider_id: Optional[_builtins.str] = None,
                       name: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudKeystoreResult:
    """
    Use this data source to get the `ID` of a cloud keystore in Venafi Control Plane, referenced by its name and parent
    cloud provider ID. You can use `get_cloud_provider` data source to obtain the ID of the parent cloud provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_venafi as venafi

    # Find a cloud keystore with a static cloud provider id
    ck_example_by_id = venafi.get_cloud_keystore(cloud_provider_id="e48897d0-2762-11ef-8fab-79ac590dd358",
        name="Cloud Keystore Example")
    # Find a cloud keystore by using venafi_cloud_provider data source as input
    ck_example = venafi.get_cloud_keystore(cloud_provider_id=cp_example["id"],
        name="Cloud Keystore example")
    ```


    :param _builtins.str cloud_provider_id: ID of the cloud provider whom the cloud keystore to look up belongs to.
    :param _builtins.str name: Name of the cloud keystore to look up.
    """
    __args__ = dict()
    __args__['cloudProviderId'] = cloud_provider_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('venafi:index/getCloudKeystore:getCloudKeystore', __args__, opts=opts, typ=GetCloudKeystoreResult).value

    return AwaitableGetCloudKeystoreResult(
        cloud_provider_id=pulumi.get(__ret__, 'cloud_provider_id'),
        id=pulumi.get(__ret__, 'id'),
        machine_identities_count=pulumi.get(__ret__, 'machine_identities_count'),
        name=pulumi.get(__ret__, 'name'),
        type=pulumi.get(__ret__, 'type'))
def get_cloud_keystore_output(cloud_provider_id: Optional[pulumi.Input[_builtins.str]] = None,
                              name: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudKeystoreResult]:
    """
    Use this data source to get the `ID` of a cloud keystore in Venafi Control Plane, referenced by its name and parent
    cloud provider ID. You can use `get_cloud_provider` data source to obtain the ID of the parent cloud provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_venafi as venafi

    # Find a cloud keystore with a static cloud provider id
    ck_example_by_id = venafi.get_cloud_keystore(cloud_provider_id="e48897d0-2762-11ef-8fab-79ac590dd358",
        name="Cloud Keystore Example")
    # Find a cloud keystore by using venafi_cloud_provider data source as input
    ck_example = venafi.get_cloud_keystore(cloud_provider_id=cp_example["id"],
        name="Cloud Keystore example")
    ```


    :param _builtins.str cloud_provider_id: ID of the cloud provider whom the cloud keystore to look up belongs to.
    :param _builtins.str name: Name of the cloud keystore to look up.
    """
    __args__ = dict()
    __args__['cloudProviderId'] = cloud_provider_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('venafi:index/getCloudKeystore:getCloudKeystore', __args__, opts=opts, typ=GetCloudKeystoreResult)
    return __ret__.apply(lambda __response__: GetCloudKeystoreResult(
        cloud_provider_id=pulumi.get(__response__, 'cloud_provider_id'),
        id=pulumi.get(__response__, 'id'),
        machine_identities_count=pulumi.get(__response__, 'machine_identities_count'),
        name=pulumi.get(__response__, 'name'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CloudKeystoreInstallationArgs', 'CloudKeystoreInstallation']

@pulumi.input_type
class CloudKeystoreInstallationArgs:
    def __init__(__self__, *,
                 certificate_id: pulumi.Input[_builtins.str],
                 cloud_keystore_id: pulumi.Input[_builtins.str],
                 arn: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_certificate_name: Optional[pulumi.Input[_builtins.str]] = None,
                 gcm_cert_scope: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CloudKeystoreInstallation resource.
        :param pulumi.Input[_builtins.str] certificate_id: ID of the certificate to be provisioned to the given `keystore_id`.
        :param pulumi.Input[_builtins.str] cloud_keystore_id: ID of the cloud keystore where the certificate will be provisioned.
        :param pulumi.Input[_builtins.str] arn: ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        :param pulumi.Input[_builtins.str] cloud_certificate_name: Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        :param pulumi.Input[_builtins.str] gcm_cert_scope: The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        pulumi.set(__self__, "certificate_id", certificate_id)
        pulumi.set(__self__, "cloud_keystore_id", cloud_keystore_id)
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if cloud_certificate_name is not None:
            pulumi.set(__self__, "cloud_certificate_name", cloud_certificate_name)
        if gcm_cert_scope is not None:
            pulumi.set(__self__, "gcm_cert_scope", gcm_cert_scope)

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the certificate to be provisioned to the given `keystore_id`.
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "certificate_id", value)

    @_builtins.property
    @pulumi.getter(name="cloudKeystoreId")
    def cloud_keystore_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the cloud keystore where the certificate will be provisioned.
        """
        return pulumi.get(self, "cloud_keystore_id")

    @cloud_keystore_id.setter
    def cloud_keystore_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud_keystore_id", value)

    @_builtins.property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "arn", value)

    @_builtins.property
    @pulumi.getter(name="cloudCertificateName")
    def cloud_certificate_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        """
        return pulumi.get(self, "cloud_certificate_name")

    @cloud_certificate_name.setter
    def cloud_certificate_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_certificate_name", value)

    @_builtins.property
    @pulumi.getter(name="gcmCertScope")
    def gcm_cert_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        return pulumi.get(self, "gcm_cert_scope")

    @gcm_cert_scope.setter
    def gcm_cert_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gcm_cert_scope", value)


@pulumi.input_type
class _CloudKeystoreInstallationState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_certificate_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 cloud_certificate_name: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_keystore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcm_cert_scope: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CloudKeystoreInstallation resources.
        :param pulumi.Input[_builtins.str] arn: ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        :param pulumi.Input[_builtins.str] certificate_id: ID of the certificate to be provisioned to the given `keystore_id`.
        :param pulumi.Input[_builtins.str] cloud_certificate_id: The ID of the provisioned certificate within the Cloud Keystore
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] cloud_certificate_metadata: Metadata of the provisioned certificate from the Cloud Keystore
        :param pulumi.Input[_builtins.str] cloud_certificate_name: Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        :param pulumi.Input[_builtins.str] cloud_keystore_id: ID of the cloud keystore where the certificate will be provisioned.
        :param pulumi.Input[_builtins.str] gcm_cert_scope: The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if cloud_certificate_id is not None:
            pulumi.set(__self__, "cloud_certificate_id", cloud_certificate_id)
        if cloud_certificate_metadata is not None:
            pulumi.set(__self__, "cloud_certificate_metadata", cloud_certificate_metadata)
        if cloud_certificate_name is not None:
            pulumi.set(__self__, "cloud_certificate_name", cloud_certificate_name)
        if cloud_keystore_id is not None:
            pulumi.set(__self__, "cloud_keystore_id", cloud_keystore_id)
        if gcm_cert_scope is not None:
            pulumi.set(__self__, "gcm_cert_scope", gcm_cert_scope)

    @_builtins.property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "arn", value)

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the certificate to be provisioned to the given `keystore_id`.
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @_builtins.property
    @pulumi.getter(name="cloudCertificateId")
    def cloud_certificate_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the provisioned certificate within the Cloud Keystore
        """
        return pulumi.get(self, "cloud_certificate_id")

    @cloud_certificate_id.setter
    def cloud_certificate_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_certificate_id", value)

    @_builtins.property
    @pulumi.getter(name="cloudCertificateMetadata")
    def cloud_certificate_metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Metadata of the provisioned certificate from the Cloud Keystore
        """
        return pulumi.get(self, "cloud_certificate_metadata")

    @cloud_certificate_metadata.setter
    def cloud_certificate_metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "cloud_certificate_metadata", value)

    @_builtins.property
    @pulumi.getter(name="cloudCertificateName")
    def cloud_certificate_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        """
        return pulumi.get(self, "cloud_certificate_name")

    @cloud_certificate_name.setter
    def cloud_certificate_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_certificate_name", value)

    @_builtins.property
    @pulumi.getter(name="cloudKeystoreId")
    def cloud_keystore_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the cloud keystore where the certificate will be provisioned.
        """
        return pulumi.get(self, "cloud_keystore_id")

    @cloud_keystore_id.setter
    def cloud_keystore_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_keystore_id", value)

    @_builtins.property
    @pulumi.getter(name="gcmCertScope")
    def gcm_cert_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        return pulumi.get(self, "gcm_cert_scope")

    @gcm_cert_scope.setter
    def gcm_cert_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gcm_cert_scope", value)


@pulumi.type_token("venafi:index/cloudKeystoreInstallation:CloudKeystoreInstallation")
class CloudKeystoreInstallation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 arn: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_certificate_name: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_keystore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcm_cert_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provisions a certificate from Venafi Control Plane's inventory to any of the supported Cloud Providers: Amazon
        Certificate Manager, Azure KeyVault or Google Certificate Manager. Exports the ID of the provisioned certificate:
        certificate name for AKV and GCM or ARN for ACM.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_venafi as venafi

        # Provision a certificate to cloud keystore with static values
        ck_installation_example_by_id = venafi.CloudKeystoreInstallation("ck_installation_example_by_id",
            cloud_keystore_id="e48897d0-2762-11ef-198k-79ac590dd358",
            certificate_id="1877af16-2762-11ef-8fab-cc123456ff7",
            cloud_certificate_name="com-terraform-example-com")
        # Provision a certificate to cloud keystore
        ck_installation_example = venafi.CloudKeystoreInstallation("ck_installation_example",
            cloud_keystore_id=ck_example["id"],
            certificate_id=certificate_example["certificateId"],
            cloud_certificate_name=certificate_example["commonName"])
        ```

        ## Import

        Using `pulumi import`, import a Machine Identity from Venafi Control Plane using their ID. For example:

        ```sh
        $ pulumi import venafi:index/cloudKeystoreInstallation:CloudKeystoreInstallation example 2155bd32-2234-22ac-7cfd-ff1198845aa2
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] arn: ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        :param pulumi.Input[_builtins.str] certificate_id: ID of the certificate to be provisioned to the given `keystore_id`.
        :param pulumi.Input[_builtins.str] cloud_certificate_name: Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        :param pulumi.Input[_builtins.str] cloud_keystore_id: ID of the cloud keystore where the certificate will be provisioned.
        :param pulumi.Input[_builtins.str] gcm_cert_scope: The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CloudKeystoreInstallationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provisions a certificate from Venafi Control Plane's inventory to any of the supported Cloud Providers: Amazon
        Certificate Manager, Azure KeyVault or Google Certificate Manager. Exports the ID of the provisioned certificate:
        certificate name for AKV and GCM or ARN for ACM.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_venafi as venafi

        # Provision a certificate to cloud keystore with static values
        ck_installation_example_by_id = venafi.CloudKeystoreInstallation("ck_installation_example_by_id",
            cloud_keystore_id="e48897d0-2762-11ef-198k-79ac590dd358",
            certificate_id="1877af16-2762-11ef-8fab-cc123456ff7",
            cloud_certificate_name="com-terraform-example-com")
        # Provision a certificate to cloud keystore
        ck_installation_example = venafi.CloudKeystoreInstallation("ck_installation_example",
            cloud_keystore_id=ck_example["id"],
            certificate_id=certificate_example["certificateId"],
            cloud_certificate_name=certificate_example["commonName"])
        ```

        ## Import

        Using `pulumi import`, import a Machine Identity from Venafi Control Plane using their ID. For example:

        ```sh
        $ pulumi import venafi:index/cloudKeystoreInstallation:CloudKeystoreInstallation example 2155bd32-2234-22ac-7cfd-ff1198845aa2
        ```

        :param str resource_name: The name of the resource.
        :param CloudKeystoreInstallationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudKeystoreInstallationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 arn: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_certificate_name: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_keystore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcm_cert_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudKeystoreInstallationArgs.__new__(CloudKeystoreInstallationArgs)

            __props__.__dict__["arn"] = arn
            if certificate_id is None and not opts.urn:
                raise TypeError("Missing required property 'certificate_id'")
            __props__.__dict__["certificate_id"] = certificate_id
            __props__.__dict__["cloud_certificate_name"] = cloud_certificate_name
            if cloud_keystore_id is None and not opts.urn:
                raise TypeError("Missing required property 'cloud_keystore_id'")
            __props__.__dict__["cloud_keystore_id"] = cloud_keystore_id
            __props__.__dict__["gcm_cert_scope"] = gcm_cert_scope
            __props__.__dict__["cloud_certificate_id"] = None
            __props__.__dict__["cloud_certificate_metadata"] = None
        super(CloudKeystoreInstallation, __self__).__init__(
            'venafi:index/cloudKeystoreInstallation:CloudKeystoreInstallation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[_builtins.str]] = None,
            certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
            cloud_certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
            cloud_certificate_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            cloud_certificate_name: Optional[pulumi.Input[_builtins.str]] = None,
            cloud_keystore_id: Optional[pulumi.Input[_builtins.str]] = None,
            gcm_cert_scope: Optional[pulumi.Input[_builtins.str]] = None) -> 'CloudKeystoreInstallation':
        """
        Get an existing CloudKeystoreInstallation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] arn: ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        :param pulumi.Input[_builtins.str] certificate_id: ID of the certificate to be provisioned to the given `keystore_id`.
        :param pulumi.Input[_builtins.str] cloud_certificate_id: The ID of the provisioned certificate within the Cloud Keystore
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] cloud_certificate_metadata: Metadata of the provisioned certificate from the Cloud Keystore
        :param pulumi.Input[_builtins.str] cloud_certificate_name: Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        :param pulumi.Input[_builtins.str] cloud_keystore_id: ID of the cloud keystore where the certificate will be provisioned.
        :param pulumi.Input[_builtins.str] gcm_cert_scope: The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudKeystoreInstallationState.__new__(_CloudKeystoreInstallationState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["certificate_id"] = certificate_id
        __props__.__dict__["cloud_certificate_id"] = cloud_certificate_id
        __props__.__dict__["cloud_certificate_metadata"] = cloud_certificate_metadata
        __props__.__dict__["cloud_certificate_name"] = cloud_certificate_name
        __props__.__dict__["cloud_keystore_id"] = cloud_keystore_id
        __props__.__dict__["gcm_cert_scope"] = gcm_cert_scope
        return CloudKeystoreInstallation(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def arn(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ARN of the AWS certificate. Use it to provision the VCP certificate to an existing ACM certificate, instead of a new one. Only valid for ACM keystores.
        """
        return pulumi.get(self, "arn")

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the certificate to be provisioned to the given `keystore_id`.
        """
        return pulumi.get(self, "certificate_id")

    @_builtins.property
    @pulumi.getter(name="cloudCertificateId")
    def cloud_certificate_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the provisioned certificate within the Cloud Keystore
        """
        return pulumi.get(self, "cloud_certificate_id")

    @_builtins.property
    @pulumi.getter(name="cloudCertificateMetadata")
    def cloud_certificate_metadata(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        """
        Metadata of the provisioned certificate from the Cloud Keystore
        """
        return pulumi.get(self, "cloud_certificate_metadata")

    @_builtins.property
    @pulumi.getter(name="cloudCertificateName")
    def cloud_certificate_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name for the provisioned certificate in the keystore. If the name already exists, the provisioning will replace the previous certificate with the one from `certificate_id`. Only valid for AKV and GCM keystores.
        """
        return pulumi.get(self, "cloud_certificate_name")

    @_builtins.property
    @pulumi.getter(name="cloudKeystoreId")
    def cloud_keystore_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the cloud keystore where the certificate will be provisioned.
        """
        return pulumi.get(self, "cloud_keystore_id")

    @_builtins.property
    @pulumi.getter(name="gcmCertScope")
    def gcm_cert_scope(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The GCM certificate scope of the certificate. Only valid for GCM keystores. Supported values from GCM API documentation: DEFAULT, EDGE_CACHE, ALL_REGIONS.
        """
        return pulumi.get(self, "gcm_cert_scope")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCloudProviderResult',
    'AwaitableGetCloudProviderResult',
    'get_cloud_provider',
    'get_cloud_provider_output',
]

@pulumi.output_type
class GetCloudProviderResult:
    """
    A collection of values returned by getCloudProvider.
    """
    def __init__(__self__, id=None, keystores_count=None, name=None, status=None, status_details=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keystores_count and not isinstance(keystores_count, int):
            raise TypeError("Expected argument 'keystores_count' to be a int")
        pulumi.set(__self__, "keystores_count", keystores_count)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if status_details and not isinstance(status_details, str):
            raise TypeError("Expected argument 'status_details' to be a str")
        pulumi.set(__self__, "status_details", status_details)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="keystoresCount")
    def keystores_count(self) -> _builtins.int:
        """
        Number of Cloud Keystores configured with the Cloud Provider
        """
        return pulumi.get(self, "keystores_count")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the Cloud Provider. Either `VALIDATED` or `NOT_VALIDATED`.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="statusDetails")
    def status_details(self) -> _builtins.str:
        """
        The details of the Cloud Provider status. If the status is `VALIDATED`, this value will be empty.
        """
        return pulumi.get(self, "status_details")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The Cloud Provider type. Either `AWS`, `AZURE` or `GCP`
        """
        return pulumi.get(self, "type")


class AwaitableGetCloudProviderResult(GetCloudProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudProviderResult(
            id=self.id,
            keystores_count=self.keystores_count,
            name=self.name,
            status=self.status,
            status_details=self.status_details,
            type=self.type)


def get_cloud_provider(name: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudProviderResult:
    """
    Use this data source to get the `ID` of a cloud provider in Venafi Control Plane, referenced by its name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_venafi as venafi

    # Find a cloud provider
    cp_example = venafi.get_cloud_provider(name="Cloud Provider Example")
    ```


    :param _builtins.str name: Name of the Cloud Provider to look up.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('venafi:index/getCloudProvider:getCloudProvider', __args__, opts=opts, typ=GetCloudProviderResult).value

    return AwaitableGetCloudProviderResult(
        id=pulumi.get(__ret__, 'id'),
        keystores_count=pulumi.get(__ret__, 'keystores_count'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'),
        status_details=pulumi.get(__ret__, 'status_details'),
        type=pulumi.get(__ret__, 'type'))
def get_cloud_provider_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudProviderResult]:
    """
    Use this data source to get the `ID` of a cloud provider in Venafi Control Plane, referenced by its name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_venafi as venafi

    # Find a cloud provider
    cp_example = venafi.get_cloud_provider(name="Cloud Provider Example")
    ```


    :param _builtins.str name: Name of the Cloud Provider to look up.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('venafi:index/getCloudProvider:getCloudProvider', __args__, opts=opts, typ=GetCloudProviderResult)
    return __ret__.apply(lambda __response__: GetCloudProviderResult(
        id=pulumi.get(__response__, 'id'),
        keystores_count=pulumi.get(__response__, 'keystores_count'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status'),
        status_details=pulumi.get(__response__, 'status_details'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('venafi')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def access_token(self) -> Optional[str]:
        """
        Access token for Venafi TLSPDC, user should use this for authentication
        """
        return __config__.get('accessToken')

    @_builtins.property
    def api_key(self) -> Optional[str]:
        """
        API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
        """
        return __config__.get('apiKey')

    @_builtins.property
    def client_id(self) -> Optional[str]:
        """
        application that will be using the token
        """
        return __config__.get('clientId')

    @_builtins.property
    def dev_mode(self) -> Optional[bool]:
        """
        When set to true, the resulting certificate will be issued by an ephemeral, no trust CA rather than enrolling using Venafi as a Service or Trust Protection Platform. Useful for development and testing
        """
        return __config__.get_bool('devMode')

    @_builtins.property
    def external_jwt(self) -> Optional[str]:
        """
        JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
        """
        return __config__.get('externalJwt')

    @_builtins.property
    def p12_cert_data(self) -> Optional[str]:
        """
        Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        """
        return __config__.get('p12CertData')

    @_builtins.property
    def p12_cert_filename(self) -> Optional[str]:
        """
        Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        """
        return __config__.get('p12CertFilename')

    @_builtins.property
    def p12_cert_password(self) -> Optional[str]:
        """
        Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
        """
        return __config__.get('p12CertPassword')

    @_builtins.property
    def skip_retirement(self) -> Optional[bool]:
        return __config__.get_bool('skipRetirement')

    @_builtins.property
    def token_url(self) -> Optional[str]:
        """
        Endpoint URL to request new Venafi Control Plane access tokens
        """
        return __config__.get('tokenUrl')

    @_builtins.property
    def tpp_password(self) -> Optional[str]:
        """
        Password for WebSDK user. Example: password
        """
        return __config__.get('tppPassword')

    @_builtins.property
    def tpp_username(self) -> Optional[str]:
        """
        WebSDK user for Venafi TLSPDC. Example: admin
        """
        return __config__.get('tppUsername')

    @_builtins.property
    def trust_bundle(self) -> Optional[str]:
        """
        Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
        Example:
          trust_bundle = "${file("chain.pem")}"
        """
        return __config__.get('trustBundle')

    @_builtins.property
    def url(self) -> Optional[str]:
        """
        The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
        """
        return __config__.get('url')

    @_builtins.property
    def zone(self) -> Optional[str]:
        """
        DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
        Example for Platform: testPolicy\\\\vault
        Example for Venafi as a Service: myApp\\\\Default
        """
        return __config__.get('zone')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dev_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_jwt: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_data: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_filename: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_password: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_retirement: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_url: Optional[pulumi.Input[_builtins.str]] = None,
                 tpp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 tpp_username: Optional[pulumi.Input[_builtins.str]] = None,
                 trust_bundle: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[_builtins.str] access_token: Access token for Venafi TLSPDC, user should use this for authentication
        :param pulumi.Input[_builtins.str] api_key: API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
        :param pulumi.Input[_builtins.str] client_id: application that will be using the token
        :param pulumi.Input[_builtins.bool] dev_mode: When set to true, the resulting certificate will be issued by an ephemeral, no trust CA rather than enrolling using Venafi as a Service or Trust Protection Platform. Useful for development and testing
        :param pulumi.Input[_builtins.str] external_jwt: JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
        :param pulumi.Input[_builtins.str] p12_cert_data: Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        :param pulumi.Input[_builtins.str] p12_cert_filename: Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        :param pulumi.Input[_builtins.str] p12_cert_password: Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
        :param pulumi.Input[_builtins.str] token_url: Endpoint URL to request new Venafi Control Plane access tokens
        :param pulumi.Input[_builtins.str] tpp_password: Password for WebSDK user. Example: password
        :param pulumi.Input[_builtins.str] tpp_username: WebSDK user for Venafi TLSPDC. Example: admin
        :param pulumi.Input[_builtins.str] trust_bundle: Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
               Example:
                 trust_bundle = "${file("chain.pem")}"
        :param pulumi.Input[_builtins.str] url: The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
        :param pulumi.Input[_builtins.str] zone: DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
               Example for Platform: testPolicy\\\\vault
               Example for Venafi as a Service: myApp\\\\Default
        """
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if api_key is not None:
            pulumi.set(__self__, "api_key", api_key)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if dev_mode is not None:
            pulumi.set(__self__, "dev_mode", dev_mode)
        if external_jwt is not None:
            pulumi.set(__self__, "external_jwt", external_jwt)
        if p12_cert_data is not None:
            pulumi.set(__self__, "p12_cert_data", p12_cert_data)
        if p12_cert_filename is not None:
            pulumi.set(__self__, "p12_cert_filename", p12_cert_filename)
        if p12_cert_password is not None:
            pulumi.set(__self__, "p12_cert_password", p12_cert_password)
        if skip_retirement is not None:
            pulumi.set(__self__, "skip_retirement", skip_retirement)
        if token_url is not None:
            pulumi.set(__self__, "token_url", token_url)
        if tpp_password is not None:
            warnings.warn(""", please use access_token instead""", DeprecationWarning)
            pulumi.log.warn("""tpp_password is deprecated: , please use access_token instead""")
        if tpp_password is not None:
            pulumi.set(__self__, "tpp_password", tpp_password)
        if tpp_username is not None:
            warnings.warn(""", please use access_token instead""", DeprecationWarning)
            pulumi.log.warn("""tpp_username is deprecated: , please use access_token instead""")
        if tpp_username is not None:
            pulumi.set(__self__, "tpp_username", tpp_username)
        if trust_bundle is not None:
            pulumi.set(__self__, "trust_bundle", trust_bundle)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access token for Venafi TLSPDC, user should use this for authentication
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_token", value)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        application that will be using the token
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="devMode")
    def dev_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When set to true, the resulting certificate will be issued by an ephemeral, no trust CA rather than enrolling using Venafi as a Service or Trust Protection Platform. Useful for development and testing
        """
        return pulumi.get(self, "dev_mode")

    @dev_mode.setter
    def dev_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dev_mode", value)

    @_builtins.property
    @pulumi.getter(name="externalJwt")
    def external_jwt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
        """
        return pulumi.get(self, "external_jwt")

    @external_jwt.setter
    def external_jwt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_jwt", value)

    @_builtins.property
    @pulumi.getter(name="p12CertData")
    def p12_cert_data(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        """
        return pulumi.get(self, "p12_cert_data")

    @p12_cert_data.setter
    def p12_cert_data(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "p12_cert_data", value)

    @_builtins.property
    @pulumi.getter(name="p12CertFilename")
    def p12_cert_filename(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        """
        return pulumi.get(self, "p12_cert_filename")

    @p12_cert_filename.setter
    def p12_cert_filename(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "p12_cert_filename", value)

    @_builtins.property
    @pulumi.getter(name="p12CertPassword")
    def p12_cert_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
        """
        return pulumi.get(self, "p12_cert_password")

    @p12_cert_password.setter
    def p12_cert_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "p12_cert_password", value)

    @_builtins.property
    @pulumi.getter(name="skipRetirement")
    def skip_retirement(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "skip_retirement")

    @skip_retirement.setter
    def skip_retirement(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_retirement", value)

    @_builtins.property
    @pulumi.getter(name="tokenUrl")
    def token_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Endpoint URL to request new Venafi Control Plane access tokens
        """
        return pulumi.get(self, "token_url")

    @token_url.setter
    def token_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_url", value)

    @_builtins.property
    @pulumi.getter(name="tppPassword")
    @_utilities.deprecated(""", please use access_token instead""")
    def tpp_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for WebSDK user. Example: password
        """
        return pulumi.get(self, "tpp_password")

    @tpp_password.setter
    def tpp_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpp_password", value)

    @_builtins.property
    @pulumi.getter(name="tppUsername")
    @_utilities.deprecated(""", please use access_token instead""")
    def tpp_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        WebSDK user for Venafi TLSPDC. Example: admin
        """
        return pulumi.get(self, "tpp_username")

    @tpp_username.setter
    def tpp_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpp_username", value)

    @_builtins.property
    @pulumi.getter(name="trustBundle")
    def trust_bundle(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
        Example:
          trust_bundle = "${file("chain.pem")}"
        """
        return pulumi.get(self, "trust_bundle")

    @trust_bundle.setter
    def trust_bundle(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "trust_bundle", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
        Example for Platform: testPolicy\\\\vault
        Example for Venafi as a Service: myApp\\\\Default
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("pulumi:providers:venafi")
class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dev_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_jwt: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_data: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_filename: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_password: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_retirement: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_url: Optional[pulumi.Input[_builtins.str]] = None,
                 tpp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 tpp_username: Optional[pulumi.Input[_builtins.str]] = None,
                 trust_bundle: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The provider type for the venafi package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_token: Access token for Venafi TLSPDC, user should use this for authentication
        :param pulumi.Input[_builtins.str] api_key: API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
        :param pulumi.Input[_builtins.str] client_id: application that will be using the token
        :param pulumi.Input[_builtins.bool] dev_mode: When set to true, the resulting certificate will be issued by an ephemeral, no trust CA rather than enrolling using Venafi as a Service or Trust Protection Platform. Useful for development and testing
        :param pulumi.Input[_builtins.str] external_jwt: JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
        :param pulumi.Input[_builtins.str] p12_cert_data: Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        :param pulumi.Input[_builtins.str] p12_cert_filename: Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        :param pulumi.Input[_builtins.str] p12_cert_password: Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
        :param pulumi.Input[_builtins.str] token_url: Endpoint URL to request new Venafi Control Plane access tokens
        :param pulumi.Input[_builtins.str] tpp_password: Password for WebSDK user. Example: password
        :param pulumi.Input[_builtins.str] tpp_username: WebSDK user for Venafi TLSPDC. Example: admin
        :param pulumi.Input[_builtins.str] trust_bundle: Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
               Example:
                 trust_bundle = "${file("chain.pem")}"
        :param pulumi.Input[_builtins.str] url: The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
        :param pulumi.Input[_builtins.str] zone: DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
               Example for Platform: testPolicy\\\\vault
               Example for Venafi as a Service: myApp\\\\Default
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the venafi package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dev_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_jwt: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_data: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_filename: Optional[pulumi.Input[_builtins.str]] = None,
                 p12_cert_password: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_retirement: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_url: Optional[pulumi.Input[_builtins.str]] = None,
                 tpp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 tpp_username: Optional[pulumi.Input[_builtins.str]] = None,
                 trust_bundle: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["access_token"] = None if access_token is None else pulumi.Output.secret(access_token)
            __props__.__dict__["api_key"] = None if api_key is None else pulumi.Output.secret(api_key)
            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["dev_mode"] = pulumi.Output.from_input(dev_mode).apply(pulumi.runtime.to_json) if dev_mode is not None else None
            __props__.__dict__["external_jwt"] = None if external_jwt is None else pulumi.Output.secret(external_jwt)
            __props__.__dict__["p12_cert_data"] = p12_cert_data
            __props__.__dict__["p12_cert_filename"] = p12_cert_filename
            __props__.__dict__["p12_cert_password"] = None if p12_cert_password is None else pulumi.Output.secret(p12_cert_password)
            __props__.__dict__["skip_retirement"] = pulumi.Output.from_input(skip_retirement).apply(pulumi.runtime.to_json) if skip_retirement is not None else None
            __props__.__dict__["token_url"] = None if token_url is None else pulumi.Output.secret(token_url)
            __props__.__dict__["tpp_password"] = None if tpp_password is None else pulumi.Output.secret(tpp_password)
            __props__.__dict__["tpp_username"] = tpp_username
            __props__.__dict__["trust_bundle"] = trust_bundle
            __props__.__dict__["url"] = url
            __props__.__dict__["zone"] = zone
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accessToken", "apiKey", "externalJwt", "p12CertPassword", "tokenUrl", "tppPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'venafi',
            resource_name,
            __props__,
            opts)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Access token for Venafi TLSPDC, user should use this for authentication
        """
        return pulumi.get(self, "access_token")

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
        """
        return pulumi.get(self, "api_key")

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        application that will be using the token
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="externalJwt")
    def external_jwt(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
        """
        return pulumi.get(self, "external_jwt")

    @_builtins.property
    @pulumi.getter(name="p12CertData")
    def p12_cert_data(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        """
        return pulumi.get(self, "p12_cert_data")

    @_builtins.property
    @pulumi.getter(name="p12CertFilename")
    def p12_cert_filename(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
        """
        return pulumi.get(self, "p12_cert_filename")

    @_builtins.property
    @pulumi.getter(name="p12CertPassword")
    def p12_cert_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
        """
        return pulumi.get(self, "p12_cert_password")

    @_builtins.property
    @pulumi.getter(name="tokenUrl")
    def token_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Endpoint URL to request new Venafi Control Plane access tokens
        """
        return pulumi.get(self, "token_url")

    @_builtins.property
    @pulumi.getter(name="tppPassword")
    @_utilities.deprecated(""", please use access_token instead""")
    def tpp_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for WebSDK user. Example: password
        """
        return pulumi.get(self, "tpp_password")

    @_builtins.property
    @pulumi.getter(name="tppUsername")
    @_utilities.deprecated(""", please use access_token instead""")
    def tpp_username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        WebSDK user for Venafi TLSPDC. Example: admin
        """
        return pulumi.get(self, "tpp_username")

    @_builtins.property
    @pulumi.getter(name="trustBundle")
    def trust_bundle(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
        Example:
          trust_bundle = "${file("chain.pem")}"
        """
        return pulumi.get(self, "trust_bundle")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
        Example for Platform: testPolicy\\\\vault
        Example for Venafi as a Service: myApp\\\\Default
        """
        return pulumi.get(self, "zone")

    @pulumi.output_type
    class TerraformConfigResult:
        def __init__(__self__, result=None):
            if result and not isinstance(result, dict):
                raise TypeError("Expected argument 'result' to be a dict")
            pulumi.set(__self__, "result", result)

        @_builtins.property
        @pulumi.getter
        def result(self) -> Mapping[str, Any]:
            return pulumi.get(self, "result")

    def terraform_config(__self__) -> pulumi.Output['Provider.TerraformConfigResult']:
        """
        This function returns a Terraform config object with terraform-namecased keys,to be used with the Terraform Module Provider.
        """
        __args__ = dict()
        __args__['__self__'] = __self__
        return pulumi.runtime.call('pulumi:providers:venafi/terraformConfig', __args__, res=__self__, typ=Provider.TerraformConfigResult)




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accessToken: Optional[str]
"""
Access token for Venafi TLSPDC, user should use this for authentication
"""

apiKey: Optional[str]
"""
API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
"""

clientId: Optional[str]
"""
application that will be using the token
"""

devMode: Optional[bool]
"""
When set to true, the resulting certificate will be issued by an ephemeral, no trust CA rather than enrolling using Venafi as a Service or Trust Protection Platform. Useful for development and testing
"""

externalJwt: Optional[str]
"""
JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
"""

p12CertData: Optional[str]
"""
Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
"""

p12CertFilename: Optional[str]
"""
Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
"""

p12CertPassword: Optional[str]
"""
Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
"""

skipRetirement: Optional[bool]

tokenUrl: Optional[str]
"""
Endpoint URL to request new Venafi Control Plane access tokens
"""

tppPassword: Optional[str]
"""
Password for WebSDK user. Example: password
"""

tppUsername: Optional[str]
"""
WebSDK user for Venafi TLSPDC. Example: admin
"""

trustBundle: Optional[str]
"""
Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
Example:
  trust_bundle = "${file("chain.pem")}"
"""

url: Optional[str]
"""
The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
"""

zone: Optional[str]
"""
DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
Example for Platform: testPolicy\\\\vault
Example for Venafi as a Service: myApp\\\\Default
"""

